summaryrefslogtreecommitdiffstats
path: root/src/video_core/shader/registry.h
diff options
context:
space:
mode:
authorReinUsesLisp <reinuseslisp@airmail.cc>2020-02-29 00:53:10 +0100
committerReinUsesLisp <reinuseslisp@airmail.cc>2020-03-09 22:40:06 +0100
commite8efd5a90100a86899e31a4de0137e915e0e0366 (patch)
tree586964f8bf2036517d7fb40c2f93b9e7e1bb058b /src/video_core/shader/registry.h
parentgl_shader_cache: Rework shader cache and remove post-specializations (diff)
downloadyuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar.gz
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar.bz2
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar.lz
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar.xz
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.tar.zst
yuzu-e8efd5a90100a86899e31a4de0137e915e0e0366.zip
Diffstat (limited to '')
-rw-r--r--src/video_core/shader/registry.h (renamed from src/video_core/shader/const_buffer_locker.h)30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/video_core/shader/const_buffer_locker.h b/src/video_core/shader/registry.h
index 7c6f7bbdd..a5487e1d7 100644
--- a/src/video_core/shader/const_buffer_locker.h
+++ b/src/video_core/shader/registry.h
@@ -20,21 +20,21 @@ using BindlessSamplerMap =
std::unordered_map<std::pair<u32, u32>, Tegra::Engines::SamplerDescriptor, Common::PairHash>;
/**
* The ConstBufferLocker is a class use to interface the 3D and compute engines with the shader
* compiler. with it, the shader can obtain required data from GPU state and store it for disk
* shader compilation.
*/
-class ConstBufferLocker {
+class Registry {
public:
- explicit ConstBufferLocker(Tegra::Engines::ShaderType shader_stage,
- VideoCore::GuestDriverProfile stored_guest_driver_profile);
+ explicit Registry(Tegra::Engines::ShaderType shader_stage,
+ VideoCore::GuestDriverProfile stored_guest_driver_profile);
- explicit ConstBufferLocker(Tegra::Engines::ShaderType shader_stage,
- Tegra::Engines::ConstBufferEngineInterface& engine);
+ explicit Registry(Tegra::Engines::ShaderType shader_stage,
+ Tegra::Engines::ConstBufferEngineInterface& engine);
- ~ConstBufferLocker();
+ ~Registry();
- /// Retrieves a key from the locker, if it's registered, it will give the registered value, if
+ /// Retrieves a key from the registry, if it's registered, it will give the registered value, if
/// not it will obtain it from maxwell3d and register it.
std::optional<u32> ObtainKey(u32 buffer, u32 offset);
@@ -53,15 +53,15 @@ public:
/// Inserts a bindless sampler key.
void InsertBindlessSampler(u32 buffer, u32 offset, Tegra::Engines::SamplerDescriptor sampler);
/// Set the bound buffer for this locker.
void SetBoundBuffer(u32 buffer);
- /// Checks keys and samplers against engine's current const buffers. Returns true if they are
- /// the same value, false otherwise;
+ /// Checks keys and samplers against engine's current const buffers.
+ /// Returns true if they are the same value, false otherwise.
bool IsConsistent() const;
- /// Returns true if the keys are equal to the other ones in the locker.
- bool HasEqualKeys(const ConstBufferLocker& rhs) const;
+ /// Returns true if the keys are equal to the other ones in the registry.
+ bool HasEqualKeys(const Registry& rhs) const;
/// Gives an getter to the const buffer keys in the database.
const KeyMap& GetKeys() const {
@@ -20,21 +20,21 @@ using BindlessSamplerMap =
std::unordered_map<std::pair<u32, u32>, Tegra::Engines::SamplerDescriptor, Common::PairHash>;
/**
- * The ConstBufferLocker is a class use to interface the 3D and compute engines with the shader
- * compiler. with it, the shader can obtain required data from GPU state and store it for disk
- * shader compilation.
+ * The Registry is a class use to interface the 3D and compute engines with the shader compiler.
+ * With it, the shader can obtain required data from GPU state and store it for disk shader
+ * compilation.
*/
@@ -53,15 +53,15 @@ public:
/// Inserts a bindless sampler key.
void InsertBindlessSampler(u32 buffer, u32 offset, Tegra::Engines::SamplerDescriptor sampler);
- /// Set the bound buffer for this locker.
+ /// Set the bound buffer for this registry.
void SetBoundBuffer(u32 buffer);